@@ -422,12 +422,7 @@ class FieldArgDict(ParentFieldArg):
             return
         if not isinstance(val, dict):
             raise ValidateError("Invalid value")
-        if isinstance(val, collections.OrderedDict):
-            value_list = list(val.items())
-        else:
-            value_list = sorted(val.items(), key=lambda t: t[0])
-        # value_list is a list of tuples [(key, value), ... ]
-        typed_list = [ (key, self._typematch(value, self.field_type)) for key,value in value_list ]
+        typed_list = [ (key, self._typematch(value, self.field_type)) for key,value in val.items() ]
         self._value = collections.OrderedDict(typed_list)
 
     value = property(get_value, set_value)
@@ -1272,7 +1267,7 @@ class Widget(tag.Part):
 
 
     def add_hiddens(self, form, page=None):
-        "Used to add ident and four hidden fields to a form, requires this widget to have these hidden fields"
+        "Used to add ident and four hidden fields to a form"
         # all submissions always have an 'ident' hidden field to provide the ident of the calling page
         if page is not None:
             form.append(tag.ClosedPart(tag_name="input",
@@ -1299,6 +1294,7 @@ class Widget(tag.Part):
                                        attribs ={"name":self.get_formname('hidden_field3'),
                                                  "value":self.get_field_value('hidden_field3'),
                                                  "type":"hidden"}))
+
         # fourth hidden field on the form
         if self.get_field_value('hidden_field4'):
             form.append(tag.ClosedPart(tag_name="input",
