@@ -54,6 +54,10 @@ SKIPOLE.inallowedlist =  function (item, allowed_values) {
 SKIPOLE.setfields = function(result) {
     try {
        // result is the contents of a json page listing widgfields and values
+       if ("ClearAllErrors" in result) {
+           // Clear errors in the page
+           SKIPOLE.clear_all_errors();
+           }
        if ("CatchToHTML" in result) {
            // Set the SKIPOLE.CatchToHTML variable to the given URL
            SKIPOLE.CatchToHTML = result["CatchToHTML"];
@@ -484,7 +488,66 @@ SKIPOLE.BaseWidget.prototype.set_attribute = function (attname, fieldarg, result
         }
     };
 
-
+// sets four hidden fields of a form
+SKIPOLE.BaseWidget.prototype.sethiddenfields = function(fieldlist, result) {
+    // alter hidden_fields in the form, or append new ones if they dont exist
+    let formtag = this.widg.find("form");
+    if (formtag.length !== 1){
+        return;
+        }
+    // hidden_field1
+    let hf1 = this.fieldarg_in_result('hidden_field1', result, fieldlist);
+    if (hf1 !== undefined) {
+        let find_field_name = "input:hidden[name=\"" + this.formname('hidden_field1') + "\"]";
+        let isfield = this.widg.find(find_field_name);
+        if (isfield.length){
+            isfield.first().val(hf1);
+            }
+        else {
+            let hftagstring = "<input type='hidden' name=\"" + this.formname('hidden_field1') + "\" value=\"" + hf1 +"\">";
+            formtag.append(hftagstring);
+            }
+        }
+    // hidden_field2
+    let hf2 = this.fieldarg_in_result('hidden_field2', result, fieldlist);
+    if (hf2 !== undefined) {
+        let find_field_name = "input:hidden[name=\"" + this.formname('hidden_field2') + "\"]";
+        let isfield = this.widg.find(find_field_name);
+        if (isfield.length){
+            isfield.first().val(hf2);
+            }
+        else {
+            let hftagstring = "<input type='hidden' name=\"" + this.formname('hidden_field2') + "\" value=\"" + hf2 +"\">";
+            formtag.append(hftagstring);
+            }
+        }
+    // hidden_field3
+    let hf3 = this.fieldarg_in_result('hidden_field3', result, fieldlist);
+    if (hf3 !== undefined) {
+        let find_field_name = "input:hidden[name=\"" + this.formname('hidden_field3') + "\"]";
+        let isfield = this.widg.find(find_field_name);
+        if (isfield.length){
+            isfield.first().val(hf3);
+            }
+        else {
+            let hftagstring = "<input type='hidden' name=\"" + this.formname('hidden_field3') + "\" value=\"" + hf3 +"\">";
+            formtag.append(hftagstring);
+            }
+        }
+    // hidden_field4
+    let hf4 = this.fieldarg_in_result('hidden_field4', result, fieldlist);
+    if (hf4 !== undefined) {
+        let find_field_name = "input:hidden[name=\"" + this.formname('hidden_field4') + "\"]";
+        let isfield = this.widg.find(find_field_name);
+        if (isfield.length){
+            isfield.first().val(hf4);
+            }
+        else {
+            let hftagstring = "<input type='hidden' name=\"" + this.formname('hidden_field4') + "\" value=\"" + hf4 +"\">";
+            formtag.append(hftagstring);
+            }
+        }
+    };
 
 // given href, and a get field with new value, returns new href with changed get field
 SKIPOLE.BaseWidget.prototype.setgetfield = function(href, fieldarg, fieldvalue) {
@@ -699,4 +762,16 @@ SKIPOLE.BaseWidget.prototype.clear_error = function() {
     };
 
 
-
+// clear errors on the page
+SKIPOLE.clear_all_errors = function() {
+    $('[data-status="error"]').each(function() {
+        // for each widget
+        var thiselement = $(this);
+        // get the widget of this thiselement
+        var widg_id = thiselement.prop('id');
+        if (widg_id in SKIPOLE.widgets) {
+            var this_widg = SKIPOLE.widgets[widg_id];
+            this_widg.clear_error();
+            }
+    })
+}
